==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/costmanagement/kotlin/inputs/GetReportByBillingAccountPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.costmanagement.kotlin.inputs

import com.pulumi.azurenative.costmanagement.inputs.GetReportByBillingAccountPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property billingAccountId BillingAccount ID
 * @property reportName Report Name.
 */
public data class GetReportByBillingAccountPlainArgs(
    public val billingAccountId: String,
    public val reportName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.costmanagement.inputs.GetReportByBillingAccountPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.costmanagement.inputs.GetReportByBillingAccountPlainArgs =
        com.pulumi.azurenative.costmanagement.inputs.GetReportByBillingAccountPlainArgs.builder()
            .billingAccountId(billingAccountId.let({ args0 -> args0 }))
            .reportName(reportName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetReportByBillingAccountPlainArgs].
 */
@PulumiTagMarker
public class GetReportByBillingAccountPlainArgsBuilder internal constructor() {
    private var billingAccountId: String? = null

    private var reportName: String? = null

    /**
     * @param value BillingAccount ID
     */
    @JvmName("lcewqguerixofhoa")
    public suspend fun billingAccountId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.billingAccountId = mapped
    }

    /**
     * @param value Report Name.
     */
    @JvmName("lmvxajfweclcwvob")
    public suspend fun reportName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.reportName = mapped
    }

    internal fun build(): GetReportByBillingAccountPlainArgs = GetReportByBillingAccountPlainArgs(
        billingAccountId = billingAccountId ?: throw PulumiNullFieldException("billingAccountId"),
        reportName = reportName ?: throw PulumiNullFieldException("reportName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/costmanagement/kotlin/inputs/GetReportByBillingAccountPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.costmanagement.kotlin.inputs

import com.pulumi.azurenative.costmanagement.inputs.GetReportByBillingAccountPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property billingAccountId BillingAccount ID
 * @property reportName Report Name.
 */
public data class GetReportByBillingAccountPlainArgs(
    public val billingAccountId: String,
    public val reportName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.costmanagement.inputs.GetReportByBillingAccountPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.costmanagement.inputs.GetReportByBillingAccountPlainArgs =
        com.pulumi.azurenative.costmanagement.inputs.GetReportByBillingAccountPlainArgs.builder()
            .billingAccountId(billingAccountId.let({ args0 -> args0 }))
            .reportName(reportName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetReportByBillingAccountPlainArgs].
 */
@PulumiTagMarker
public class GetReportByBillingAccountPlainArgsBuilder internal constructor() {
    private var billingAccountId: String? = null

    private var reportName: String? = null

    /**
     * @param value BillingAccount ID
     */
    @JvmName("twherlrjigunyiio")
    public suspend fun billingAccountId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.billingAccountId = mapped
    }

    /**
     * @param value Report Name.
     */
    @JvmName("jphetoqosicflddm")
    public suspend fun reportName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.reportName = mapped
    }

    internal fun build(): GetReportByBillingAccountPlainArgs = GetReportByBillingAccountPlainArgs(
        billingAccountId = billingAccountId ?: throw PulumiNullFieldException("billingAccountId"),
        reportName = reportName ?: throw PulumiNullFieldException("reportName"),
    )
}
